<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Atallos ocultos</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Estes atallos codificados anularanse se tamén se asignan a outras accións en Preferencias → Atallos.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Atallo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Pecha a xanela ou sae do modo de pantalla completa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Seguinte imaxe</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Espazo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Última imaxe</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Anterior imaxe</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Espazo atrás (borrar)</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Cartafol persoal</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Primeira imaxe</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="93"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Iniciar en pantalla completa (pode ser útil cos xestores de fiestras de mosaico)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Fai unha captura de pantalla (obsoleto, usa captura de pantalla no seu lugar)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Fai unha captura de pantalla e gárdaa no directorio sen mostrar a GUI (obsoleto, utiliza captura de pantalla no seu lugar)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="116"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FICHEIRO1, FICHEIRO2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>resposta de erro descoñecida</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>resposta de erro descoñecida</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Un visor de imaxes sinxelo e rápido</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>Proxecto LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Desenvolvemento: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Autor: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>Ficheiros de imaxe (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Gardar o ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Cargando...) - Visor de imaxes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Produciuse un fallo na carga) - Visor de imaxes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visor de imaxes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visor de imaxes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Thumbnails</source>
        <translation>Miniaturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>EXIF Data</source>
        <translation>Datos EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Use unha tecla modificadora para borrar un atallo
no modo de edición.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="213"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="214"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="341"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Advertencia: detectouse un atallo ambiguo!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="358"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Non se acepta o atallo ambiguo.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Non se pode gardar con este formato de imaxe!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Ruta:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="50"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="51"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="134"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visor de imaxes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Annotations Toolbar</source>
        <translation>Barra de ferramentas das anotacións</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Gardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Gardar &amp;como</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>&amp;Pechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>A&amp;chegar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>A&amp;fastar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copiar ao portapapeis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Ficheiro seguinte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Ficheiro anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation type="unfinished">Abrir con...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>Ficheiros abertos &amp;recentemente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Ordenación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation type="unfinished">Atallos agochados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Abrir…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Recargar o ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>Av Páx</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>Re Páx</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Tamaño orixinal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>A&amp;xustar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Rotar en sentido &amp;horario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Rotar en sentido &amp;antihorario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>P&amp;referencias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>&amp;Print</source>
        <translation>Im&amp;primir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>First File</source>
        <translation>Primeiro ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Home</source>
        <translation>Cartafol persoal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Last File</source>
        <translation>Último ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nova xanela</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Inverter na &amp; horizontal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>Capture Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>F&amp;ull Screen</source>
        <translation>Pantalla c&amp;ompleta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Flip &amp;Vertically</source>
        <translation>Inverter na &amp;vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Pegar do portapapeis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diaporama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Show Thumbnails</source>
        <translation>Amosar miniaturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>T</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="553"/>
        <source>File Properties</source>
        <translation>Propiedades do ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="562"/>
        <source>Open &amp;Directory</source>
        <translation>Abrir &amp;directorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="574"/>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Upload the image</source>
        <translation>Enviar a imaxe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="580"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Show EXIF Data</source>
        <translation>Amosar os datos EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>No Tool</source>
        <translation>Ningunha ferramenta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Deselect all drawing tools</source>
        <translation>Desmarcar todas as ferramentas de debuxo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="615"/>
        <source>Draw Arrow</source>
        <translation>Debuxar unha frecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Draw an arrow</source>
        <translation>Debuxar unha frecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="630"/>
        <source>Draw Rectangle</source>
        <translation>Debuxar un rectángulo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="633"/>
        <source>Draw a hollow rectangle</source>
        <translation>Debuxa un rectángulo oco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Draw Circle</source>
        <translation>Debuxar un círculo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>Draw a hollow circle</source>
        <translation>Debuxar un círculo oco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Draw Number</source>
        <translation>Debuxar un número</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Draw incrementing numbers</source>
        <translation>Debuxar números de xeito incremental</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Menubar</source>
        <translation>Barra de menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>&amp;Main Toolbar</source>
        <translation type="unfinished">Barra de ferramentas principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="688"/>
        <source>Main Toolbar</source>
        <translation>Barra de ferramentas principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Barra de ferramentas das anotacións</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <location filename="../mainwindow.ui" line="710"/>
        <source>Show Outline</source>
        <translation>Amosar o bordo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="721"/>
        <source>Copy Pa&amp;th</source>
        <translation>Copiar a ruta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Copy path</source>
        <translation>Copiar a ruta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Rename</source>
        <translation type="unfinished">Renomear</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Resize</source>
        <translation>Redimensionar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>&amp;By File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>By File Name</source>
        <translation>Polo nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="766"/>
        <source>By &amp;Modification Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>By Modification Time</source>
        <translation>Por hora de modificación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="777"/>
        <source>By C&amp;reation Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>By Creation Time</source>
        <translation>Por Tempo de Creación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="788"/>
        <source>By File &amp;Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>By File Size</source>
        <translation>Por tamaño do ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="799"/>
        <source>By File &amp;Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="802"/>
        <source>By File Type</source>
        <translation>Por tipo de ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Ir a</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Barra de ferramentas</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema de iconas:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Límite de tamaño do ficheiro de miniaturas:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Cor do fondo normal:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Cor do fondo a pantalla completa:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Número máximo de ficheiros recentes:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Intervalo do diaporama (en segundos):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Show image outline by default</source>
        <translation>Amosar o bordo da imaxe de xeito predeterminado</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Amosa de xeito predeterminado a barra de ferramentas das anotacións</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Fit images when navigating</source>
        <translation>Axustar imaxes ao navegar</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensións da imaxe en miniatura:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Use a papeleira do sistema (e non preguntar)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Xanela</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Mostrar acoplamento de miniaturas por defecto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Mostrar a base de datos Exif por defecto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Mostrar a barra de menú por defecto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Mostrar a barra de ferramentas principal por defecto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Imaxe</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Smooth images on zooming</source>
        <translation>Imaxes suaves ao ampliar</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="264"/>
        <source>Shortcuts</source>
        <translation>Atallos</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="283"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="288"/>
        <source>Shortcut</source>
        <translation>Atallo</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="296"/>
        <source>Default</source>
        <translation>&quot;Restablecer os atallos aos valores predeterminados&quot;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Xeral</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="996"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Cambiar o tamaño da imaxe</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Largo</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Tamaño actual:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Novo tamaño:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Mantén a relación de aspecto</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Obter unha captura de pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Área</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Só a xanela actual</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Capturar unha área da pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Incluír o punteiro do rato</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Demora:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Incluír o marco e o título da xanela</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
</TS>
